==> dscontexai-0.0.10.tar.gz: dscontexai-0.0.10/setup.py <==
from setuptools import find_packages, setup

VERSION = "0.0.10"
DESCRIPTION = "ConteXAI"
LONG_DESCRIPTION = "xAI for everyone!"

# Setting up
setup(
    name="dscontexai",
    version=VERSION,
    author="Jovana V., Haris K., Luka M.",
    author_email="<youremail@email.com>",
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    packages=find_packages(),
    package_data={"latex_styles": ["./dscontexai/latex/neurips_2023"]},
    install_requires=[
        "asttokens==2.4.1",
        "backcall==0.2.0",
        "catboost==1.2.5",
        "cloudpickle==3.0.0",
        "comm==0.2.2",
        "contourpy==1.1.1",
        "cycler==0.12.1",
        "debugpy==1.8.1",
        "decorator==5.1.1",
        "executing==2.0.1",
        "fonttools==4.51.0",
        "graphviz==0.20.3",
        "importlib-metadata==7.1.0",
        "importlib-resources==6.4.0",
        "ipykernel==6.29.4",
        "ipython==8.12.3",
        "jedi==0.19.1",
        "joblib==1.4.0",
        "jupyter-client==8.6.1",
        "jupyter-core==5.7.2",
        "kiwisolver==1.4.5",
        "llvmlite==0.41.1",
        "matplotlib==3.7.5",
        "matplotlib-inline==0.1.7",
        "nest-asyncio==1.6.0",
        "numba==0.58.1",
        "numpy==1.24.4",
        "ordered-set==4.1.0",
        "packaging==24.0",
        "pandas==2.0.3",
        "parso==0.8.4",
        "pexpect==4.9.0",
        "pickleshare==0.7.5",
        "pillow==10.3.0",
        "platformdirs==4.2.0",
        "plotly==5.22.0",
        "prompt-toolkit==3.0.43",
        "psutil==5.9.8",
        "ptyprocess==0.7.0",
        "pure-eval==0.2.2",
        "pygments==2.17.2",
        "PyLaTeX==1.4.2",
        "pyparsing==3.1.2",
        "python-dateutil==2.9.0.post0",
        "pytz==2024.1",
        "pyzmq==26.0.0",
        "scikit-learn==1.3.2",
        "scipy==1.10.1",
        "seaborn==0.13.2",
        "shap==0.44.1",
        "six==1.16.0",
        "slicer==0.0.7",
        "stack-data==0.6.3",
        "tenacity==8.3.0",
        "threadpoolctl==3.4.0",
        "tornado==6.4",
        "tqdm==4.66.2",
        "traitlets==5.14.2",
        "typing-extensions==4.11.0",
        "tzdata==2024.1",
        "wcwidth==0.2.13",
        "zipp==3.18.1",
    ],
    keywords=["python", "first package"],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Education",
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
)

==> dscontexai-0.0.11.tar.gz: dscontexai-0.0.11/setup.py <==
from setuptools import find_packages, setup

VERSION = "0.0.11"
DESCRIPTION = "ConteXAI"
LONG_DESCRIPTION = "xAI for everyone!"

# Setting up
setup(
    name="dscontexai",
    version=VERSION,
    author="Jovana V., Haris K., Luka M.",
    author_email="<youremail@email.com>",
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    packages=find_packages(),
    package_data={"dscontexai": ["latex/neurips_2023.sty"]},
    install_requires=[
        "asttokens==2.4.1",
        "backcall==0.2.0",
        "catboost==1.2.5",
        "cloudpickle==3.0.0",
        "comm==0.2.2",
        "contourpy==1.1.1",
        "cycler==0.12.1",
        "debugpy==1.8.1",
        "decorator==5.1.1",
        "executing==2.0.1",
        "fonttools==4.51.0",
        "graphviz==0.20.3",
        "importlib-metadata==7.1.0",
        "importlib-resources==6.4.0",
        "ipykernel==6.29.4",
        "ipython==8.12.3",
        "jedi==0.19.1",
        "joblib==1.4.0",
        "jupyter-client==8.6.1",
        "jupyter-core==5.7.2",
        "kiwisolver==1.4.5",
        "llvmlite==0.41.1",
        "matplotlib==3.7.5",
        "matplotlib-inline==0.1.7",
        "nest-asyncio==1.6.0",
        "numba==0.58.1",
        "numpy==1.24.4",
        "ordered-set==4.1.0",
        "packaging==24.0",
        "pandas==2.0.3",
        "parso==0.8.4",
        "pexpect==4.9.0",
        "pickleshare==0.7.5",
        "pillow==10.3.0",
        "platformdirs==4.2.0",
        "plotly==5.22.0",
        "prompt-toolkit==3.0.43",
        "psutil==5.9.8",
        "ptyprocess==0.7.0",
        "pure-eval==0.2.2",
        "pygments==2.17.2",
        "PyLaTeX==1.4.2",
        "pyparsing==3.1.2",
        "python-dateutil==2.9.0.post0",
        "pytz==2024.1",
        "pyzmq==26.0.0",
        "scikit-learn==1.3.2",
        "scipy==1.10.1",
        "seaborn==0.13.2",
        "shap==0.44.1",
        "six==1.16.0",
        "slicer==0.0.7",
        "stack-data==0.6.3",
        "tenacity==8.3.0",
        "threadpoolctl==3.4.0",
        "tornado==6.4",
        "tqdm==4.66.2",
        "traitlets==5.14.2",
        "typing-extensions==4.11.0",
        "tzdata==2024.1",
        "wcwidth==0.2.13",
        "zipp==3.18.1",
    ],
    keywords=["python", "first package"],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Education",
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
)
